@@ -1,12 +1,19 @@
 /**************************************************************************
  Copyright:
-      (C) 2008 - 2011  Alexander Shaduri <ashaduri 'at' gmail.com>
+      (C) 2008 - 2012  Alexander Shaduri <ashaduri 'at' gmail.com>
  License: See LICENSE_gsmartcontrol.txt
 ***************************************************************************/
+/// \file
+/// \author Alexander Shaduri
+/// \ingroup applib
+/// \weakgroup applib
+/// @{
 
 #include <gtkmm.h>
 #include <gtk/gtk.h>  // gtk_* stuff
+#include <cstring>  // std::strlen
 #include <vector>
+#include <glibmm.h>
 
 #include "app_gtkmm_features.h"  // APP_GTKMM_OLD_TOOLTIPS
 
@@ -111,7 +118,7 @@ void app_gtkmm_combobox_unset_model(Gtk::ComboBox* box)
 
 namespace {
 
-	// helper function for gtkmm_set_treeview_tooltip_column()
+	/// A helper function for gtkmm_set_treeview_tooltip_column()
 	inline bool app_on_treeview_motion_notify_event_tooltip(GdkEventMotion* event, Gtk::TreeView* treeview,
 			Gtk::TreeModelColumn<Glib::ustring> tooltip_column)
 	{
@@ -130,7 +137,7 @@ namespace {
 	}
 
 
-	// helper function for gtkmm_set_iconview_tooltip_column()
+	/// A helper function for gtkmm_set_iconview_tooltip_column()
 	inline bool app_on_iconview_motion_notify_event_tooltip(GdkEventMotion* event, Gtk::IconView* iconview,
 			Gtk::TreeModelColumn<Glib::ustring> tooltip_column, Glib::RefPtr<Gtk::ListStore> model)
 	{
@@ -188,7 +195,6 @@ void gtkmm_set_iconview_tooltip_column(Gtk::IconView* iconview,
 
 
 
-
 bool app_gtkmm_icon_theme_has_icon(Glib::RefPtr<Gtk::IconTheme> theme,
 		const Glib::ustring& icon_name, int size)
 {
@@ -207,6 +213,83 @@ bool app_gtkmm_icon_theme_has_icon(Glib::RefPtr<Gtk::IconTheme> theme,
 
 
 
+namespace {
+
+	/// This has been copied from _g_utf8_make_valid() (glib-2.20.4).
+	/// _g_utf8_make_valid() is GLib's private function for auto-correcting
+	/// the potentially invalid utf-8 data.
+	inline gchar* gsc_g_utf8_make_valid (const gchar* name)
+	{
+		GString* str;
+		const gchar* remainder, *invalid;
+		gint remaining_bytes, valid_bytes;
+
+		g_return_val_if_fail (name != NULL, NULL);
+
+		str = NULL;
+		remainder = name;
+		remaining_bytes = gint(std::strlen(name));
+
+		while (remaining_bytes != 0) {
+			if (g_utf8_validate (remainder, remaining_bytes, &invalid))
+				break;
+
+			valid_bytes = gint(invalid - remainder);
+
+			if (str == NULL)
+				str = g_string_sized_new (remaining_bytes);
+
+			g_string_append_len (str, remainder, valid_bytes);
+			/* append U+FFFD REPLACEMENT CHARACTER */
+			g_string_append (str, "\357\277\275");
+
+			remaining_bytes -= valid_bytes + 1;
+			remainder = invalid + 1;
+		}
+
+		if (str == NULL)
+			return g_strdup (name);
+
+		g_string_append (str, remainder);
+
+		g_assert (g_utf8_validate (str->str, -1, NULL));
+
+		return g_string_free (str, FALSE);
+	}
+
+}
 
 
 
+Glib::ustring app_utf8_make_valid(const Glib::ustring& str)
+{
+	char* s = gsc_g_utf8_make_valid(str.c_str());
+	if (!s) {
+		return Glib::ustring();
+	}
+	Glib::ustring res(s);
+	g_free(s);
+	return res;
+}
+
+
+
+Glib::ustring app_output_make_valid(const Glib::ustring& str)
+{
+	#ifdef _WIN32
+	try {
+		return app_utf8_make_valid(Glib::locale_to_utf8(str));
+	} catch (Glib::ConvertError& e) {
+		// nothing, try to fix as it is
+	}
+	#endif
+	return app_utf8_make_valid(str);
+}
+
+
+
+
+
+
+
+/// @}
