@@ -1,8 +1,13 @@
 /**************************************************************************
  Copyright:
-      (C) 2008 - 2011  Alexander Shaduri <ashaduri 'at' gmail.com>
+      (C) 2008 - 2012  Alexander Shaduri <ashaduri 'at' gmail.com>
  License: See LICENSE_gsmartcontrol.txt
 ***************************************************************************/
+/// \file
+/// \author Alexander Shaduri
+/// \ingroup applib
+/// \weakgroup applib
+/// @{
 
 #ifndef STORAGE_DEVICE_H
 #define STORAGE_DEVICE_H
@@ -22,6 +27,11 @@
 class StorageDevice;
 
 
+/// A reference-counting pointer to StorageDevice
+typedef hz::intrusive_ptr<StorageDevice> StorageDeviceRefPtr;
+
+
+
 /// This class represents a single drive
 class StorageDevice : public hz::intrusive_ptr_referenced {
 
@@ -52,6 +62,10 @@ class StorageDevice : public hz::intrusive_ptr_referenced {
 		static std::string get_status_name(status_t status, bool use_yesno = false);
 
 
+		/// Comparison function for sorting the devices
+		static bool order_less_than(const StorageDeviceRefPtr& a, const StorageDeviceRefPtr& b);
+
+
 		/// Constructor
 		StorageDevice(const std::string& dev_or_vfile, bool is_virtual = false);
 
@@ -271,16 +285,22 @@ class StorageDevice : public hz::intrusive_ptr_referenced {
 
 
 
-typedef hz::intrusive_ptr<StorageDevice> StorageDeviceRefPtr;
-
-
-// for sorting, hard drives first
-inline bool operator< (const StorageDeviceRefPtr& d1, const StorageDeviceRefPtr& d2)
+/// Operator for sorting, hard drives first, then device name base
+inline bool operator< (const StorageDeviceRefPtr& a, const StorageDeviceRefPtr& b)
 {
-	if (d1->get_detected_type() != d2->get_detected_type()) {
-		return (d1->get_detected_type() == StorageDevice::detected_type_unknown);  // hard drives first
+// 	if (a->get_detected_type() != a->get_detected_type()) {
+// 		return (a->get_detected_type() == StorageDevice::detected_type_unknown);  // hard drives first
+// 	}
+	if (a->get_is_virtual() != b->get_is_virtual()) {
+		return int(a->get_is_virtual()) < int(b->get_is_virtual());
 	}
-	return d1->get_device_base() < d2->get_device_base();
+	if (a->get_is_virtual()) {
+		return a->get_virtual_file() < b->get_virtual_file();
+	}
+	if (a->get_device_base() != b->get_device_base()) {
+		return a->get_device_base() < b->get_device_base();
+	}
+	return a->get_type_argument() < b->get_type_argument();
 }
 
 
@@ -290,3 +310,5 @@ inline bool operator< (const StorageDeviceRefPtr& d1, const StorageDeviceRefPtr&
 
 
 #endif
+
+/// @}
