@@ -1,8 +1,13 @@
 /**************************************************************************
  Copyright:
-      (C) 2008 - 2011  Alexander Shaduri <ashaduri 'at' gmail.com>
+      (C) 2008 - 2012  Alexander Shaduri <ashaduri 'at' gmail.com>
  License: See LICENSE_gsmartcontrol.txt
 ***************************************************************************/
+/// \file
+/// \author Alexander Shaduri
+/// \ingroup gsc
+/// \weakgroup gsc
+/// @{
 
 #ifndef GSC_SETTINGS_H
 #define GSC_SETTINGS_H
@@ -12,16 +17,12 @@
 
 
 
-// Initialize ALL default settings here.
-
-// Absolute paths go to root node, relative ones go to /config and /default.
-
-// Note: There must be no degradation if /config is removed entirely
-// during runtime. /default must provide every path which /config could
-// have held.
-// ALL runtime (that is, non-config-file-writable) settings go to /runtime.
-
-
+/// Initializes ALL default settings.
+/// Absolute paths go to root node, relative ones go to /config and /default.
+/// Note: There must be no degradation if /config is removed entirely
+/// during runtime. /default must provide every path which /config could
+/// have held.
+/// ALL runtime (that is, non-config-file-writable) settings go to /runtime.
 inline void init_default_settings()
 {
 	// Populate /default
@@ -50,6 +51,7 @@ inline void init_default_settings()
 	rconfig::set_default_data("system/linux_proc_partitions_path", "/proc/partitions");  // file in linux /proc/partitions format
 	rconfig::set_default_data("system/linux_proc_devices_path", "/proc/devices");  // file in linux /proc/devices format
 	rconfig::set_default_data("system/linux_proc_scsi_scsi_path", "/proc/scsi/scsi");  // file in linux /proc/scsi/scsi format
+	rconfig::set_default_data("system/linux_proc_scsi_sg_devices_path", "/proc/scsi/sg/devices");  // file in linux /proc/scsi/sg/devices format
 	rconfig::set_default_data("system/linux_max_scan_ports", int32_t(23));  // maximum number of RAID ports to scan if no other method is available
 	rconfig::set_default_data("system/solaris_dev_path", "/dev/rdsk");  // path to /dev/rdsk for solaris.
 	rconfig::set_default_data("system/unix_sdev_path", "/dev");  // path to /dev. used by other unices
@@ -61,6 +63,9 @@ inline void init_default_settings()
 
 	rconfig::set_default_data("gui/smartctl_output_filename_format", "{model}_{serial}_{date}.txt");  // when suggesting filename
 
+	rconfig::set_default_data("gui/icons_show_device_name", false);  // text under icons
+	rconfig::set_default_data("gui/icons_show_serial_number", false);  // text under icons
+
 
 	// Populate /runtime too, just in case. The values don't really matter.
 
@@ -79,3 +84,5 @@ inline void init_default_settings()
 
 
 #endif
+
+/// @}
