@@ -1,8 +1,13 @@
 /**************************************************************************
  Copyright:
-      (C) 2003 - 2011  Alexander Shaduri <ashaduri 'at' gmail.com>
+      (C) 2003 - 2012  Alexander Shaduri <ashaduri 'at' gmail.com>
  License: See LICENSE_zlib.txt file
 ***************************************************************************/
+/// \file
+/// \author Alexander Shaduri
+/// \ingroup hz
+/// \weakgroup hz
+/// @{
 
 #ifndef HZ_DOWN_CAST_H
 #define HZ_DOWN_CAST_H
@@ -18,14 +23,13 @@
 namespace hz {
 
 
-// Perform a down cast.
-
-// This cast works with polymorphic and non-polymorphic types.
-// If RTTI is disabled, it will revert to static_cast; otherwise,
-// dynamic_cast is used for polymorphic types and static_cast
-// for non-polymorphic types.
-
-// Use with pointers only!
+/// Perform a down cast (pointers only!).
+/// This cast works with polymorphic and non-polymorphic types.
+/// If RTTI is disabled, it will revert to static_cast; otherwise,
+/// dynamic_cast is used for polymorphic types and static_cast
+/// for non-polymorphic types.
+template<typename Target, typename Source> inline
+Target down_cast(const Source& arg);
 
 
 
@@ -48,6 +52,8 @@ Target down_cast(const Source& arg)
 
 namespace internal {
 
+	/// Helper for down_cast, uses dynamic_cast unless the types are non-polymorphic,
+	/// in which case static_cast is used.
 	template<typename Target, typename Source,
 			bool Polymorphic = type_is_polymorphic<typename type_remove_pointer<Target>::type>::value
 					&& type_is_polymorphic<typename type_remove_pointer<Source>::type>::value >
@@ -60,7 +66,7 @@ namespace internal {
 	};
 
 
-	// non-polymorphic specialization
+	/// Non-polymorphic specialization
 	template<typename Target, typename Source>
 	struct down_cast_helper<Target, Source, false>
 	{
@@ -95,3 +101,5 @@ Target down_cast(const Source& arg)
 
 
 #endif
+
+/// @}
