@@ -1,6 +1,6 @@
 /**************************************************************************
  Copyright:
-      (C) 2008 - 2011  Alexander Shaduri <ashaduri 'at' gmail.com>
+      (C) 2008 - 2012  Alexander Shaduri <ashaduri 'at' gmail.com>
  License: See LICENSE_zlib.txt file
 ***************************************************************************/
 
@@ -14,33 +14,23 @@
 #include "sync.h"
 
 
-// Glib-based policy.
-
-
-// Note: g_static_mutex_*lock() functions may give warnings about breaking strict-aliasing rules.
-// The warnings are completely harmless and visible on some versions of glib only.
-// However, due to their number, I decided to implement this workaround.
-
-#ifndef _WIN32
-	// same as stock version, but an additional cast to (void*) is added.
-	#define hz_glib_static_mutex_get_mutex(mutex) \
-		( g_thread_use_default_impl ? ((GMutex*) ((void*)((mutex)->static_mutex.pad))) : \
-		g_static_mutex_get_mutex_impl_shortcut(&((mutex)->runtime_mutex)) )
-
-#else
-	// win32 has different definition of this macro, so default to stock version.
-	#define hz_glib_static_mutex_get_mutex(mutex) g_static_mutex_get_mutex(mutex)
-#endif
+/**
+\file
+Glib-based policy.
+*/
 
 
+/// Lock GStaticMutex
 #define hz_glib_static_mutex_lock(mutex) \
-	g_mutex_lock(hz_glib_static_mutex_get_mutex(mutex))
+	g_mutex_lock(g_static_mutex_get_mutex(mutex))
 
+/// Try locking GStaticMutex
 #define hz_glib_static_mutex_trylock(mutex) \
-	g_mutex_trylock(hz_glib_static_mutex_get_mutex(mutex))
+	g_mutex_trylock(g_static_mutex_get_mutex(mutex))
 
+/// Unlock GStaticMutex
 #define hz_glib_static_mutex_unlock(mutex) \
-	g_mutex_unlock(hz_glib_static_mutex_get_mutex(mutex))
+	g_mutex_unlock(g_static_mutex_get_mutex(mutex))
 
 
 
@@ -48,7 +38,7 @@
 namespace hz {
 
 
-
+/// C++ Wrapper for Glib mutex
 class MutexGlib : public hz::noncopyable {
 	public:
 		typedef GStaticMutex native_type;
@@ -81,6 +71,7 @@ class MutexGlib : public hz::noncopyable {
 
 
 
+/// C++ Wrapper for Glib recursive mutex
 class RecMutexGlib : public hz::noncopyable {
 	public:
 		typedef GStaticRecMutex native_type;
@@ -113,6 +104,7 @@ class RecMutexGlib : public hz::noncopyable {
 
 
 
+/// C++ Wrapper for Glib RW lock
 class RWMutexGlib : public hz::noncopyable {
 	public:
 		typedef GStaticRWLock native_type;
@@ -154,24 +146,22 @@ class RWMutexGlib : public hz::noncopyable {
 
 
 
-// Native type notes:
-// MutexGlib's underlying structure is neither guaranteed to be
-// recursive nor to be non-recursive.
-// All these mutexes won't do anything unless gthread is initialized.
-
-// Note: For this policy to work, you MUST initialize GThread system
-// by calling one of the following (doesn't matter which exactly) beforehand:
-// Glib::thread_init();  // glibmm
-// or
-// g_thread_init(NULL);  // glib
-// or
-// SyncPolicyGlib::init();  // sync's wrapper
-
-// If you don't do it, the operations will silently do nothing.
-
-
-// Glib doesn't provide any means to detect errors, so no exceptions here.
-
+/// Native type notes:
+/// MutexGlib's underlying structure is neither guaranteed to be
+/// recursive nor to be non-recursive.
+/// All these mutexes won't do anything unless gthread is initialized.
+/// 
+/// Note: For this policy to work, you MUST initialize GThread system
+/// by calling one of the following (doesn't matter which exactly) beforehand:
+/// Glib::thread_init();  // glibmm
+/// or
+/// g_thread_init(NULL);  // glib
+/// or
+/// SyncPolicyGlib::init();  // sync's wrapper
+/// 
+/// If you don't do it, the operations will silently do nothing.
+/// 
+/// Glib doesn't provide any means to detect errors, so no exceptions here.
 struct SyncPolicyGlib : public SyncScopedLockProvider<SyncPolicyGlib> {
 
 	// Types:
@@ -207,7 +197,7 @@ struct SyncPolicyGlib : public SyncScopedLockProvider<SyncPolicyGlib> {
 
 	// Static methods
 
-	// If threads are unavailable, this will abort.
+	/// If glib threads are unavailable, this will abort.
 	static bool init() { if (!g_thread_supported()) g_thread_init(NULL); return true; }
 
 	static void lock(Mutex& m) { m.lock(); }
