@@ -1,17 +1,34 @@
 /**************************************************************************
  Copyright:
-      (C) 2008 - 2011  Alexander Shaduri <ashaduri 'at' gmail.com>
+      (C) 2008 - 2012  Alexander Shaduri <ashaduri 'at' gmail.com>
  License: See LICENSE_zlib.txt file
 ***************************************************************************/
+/// \file
+/// \author Alexander Shaduri
+/// \ingroup libdebug
+/// \weakgroup libdebug
+/// @{
 
 #ifndef LIBDEBUG_LIBDEBUG_H
 #define LIBDEBUG_LIBDEBUG_H
 
+/**
+\file
+Main libdebug include file, includes complete libdebug functionality.
+\see libdebug_mini.h
+*/
 
 // These macros may be used to control how libdebug is built:
 
-// define ENABLE_GLIB to 1 to enable Glib option parsing support.
-// define DEBUG_BUILD to enable all levels by default.
+/// \def ENABLE_GLIB
+/// Define to 1 to enable Glib option parsing support.
+
+/// \def DEBUG_BUILD
+/// Define to 1 to enable all levels by default.
+
+
+/// \namespace debug_internal
+/// Libdebug internal implementation details
 
 
 
@@ -28,3 +45,5 @@
 
 
 #endif
+
+/// @}
